@@ -29,7 +29,7 @@ def create_bigquery_client(info=None, credential_filepath=None):
                                                                     ]
                                                             )
 
-    client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred)
+    client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred, location=lib_conf.BIGQUERY_GCLOUD_LOCATION)
     
     return client 
 
@@ -55,7 +55,7 @@ def if_table_exists(bigquery_client, table_ref):
 
 
 def create_table_from_template(dataset_name, table_name, table_scheme, table_name_surfix=None, 
-                               partition_value=None, bigquery_client=None):
+                               partition_value=None, bigquery_client=None, final_table_name=None):
     if bigquery_client is None:
         bigquery_client   = create_bigquery_client()
     
@@ -67,13 +67,14 @@ def create_table_from_template(dataset_name, table_name, table_scheme, table_nam
     
     
     logger.debug('dataset_ref=%s' , dataset_ref)
-    final_table_name = table_name    
+    if final_table_name is None:
+        final_table_name = table_name    
     
-    if table_name_surfix:
-        final_table_name = final_table_name+'_'+table_name_surfix
-        
-    if partition_value:
-        final_table_name = final_table_name+'_'+partition_value
+        if table_name_surfix:
+            final_table_name = final_table_name+'_'+table_name_surfix
+            
+        if partition_value:
+            final_table_name = final_table_name+'_'+partition_value
         
     logger.debug('final_table_name=%s' , final_table_name)
     
@@ -209,11 +210,42 @@ def default_serializable(val, none_as_empty_string=False):
             
     return value
 
+def stream_data(bigquery_client, dataset_name, table_template_name, table_scheme, table_name, data_list_to_stream, stream_datetime=None):
+    
+    errors              = []
+    created_table       = create_table_from_template(dataset_name, table_template_name, table_scheme,
+                                            final_table_name=table_name, 
+                                             bigquery_client=bigquery_client)
+            
+            
+    logger.debug('==============================================')
+    logger.debug('created_table=%s' , created_table)
+    logger.debug('==============================================')
+    
+    serialize_data_to_stream_list = []
+    for data_dict in data_list_to_stream:
+        
+        serialized_dict = {}
+        
+        for k,v in data_dict.items():
+            serialized_dict[k] = default_serializable(v)
+            
+        serialize_data_to_stream_list.append(serialized_dict)
+        
+            
+    __errors = bigquery_client.insert_rows_json(created_table, serialize_data_to_stream_list)
+            
+    if len(__errors)>0:
+        errors.extend(__errors)
+            
+    return errors
+
 def stream_data_by_datetime_partition(bigquery_client, dataset_name, table_template_name, table_scheme, data_dict_to_stream, column_name_used_to_partition=None, 
                              partition_date=False, partition_month=False, partition_year=False):
     
     errors                      = []
     partition_date_formation    = None
+    logger.debug('table_scheme=%s' , table_scheme)
     
     if column_name_used_to_partition and (partition_date or partition_month or partition_year):
         logger.debug('partition_date=%s' , partition_date)
@@ -264,10 +296,7 @@ def stream_data_by_datetime_partition(bigquery_client, dataset_name, table_templ
         #stream partiion data
         for partition_value_str, partition_list in partition_dict.items():
             
-            logger.debug('==============================================')
-            logger.debug('partition_value_str=%s' , partition_value_str)
-            logger.debug('partition_list=%s' , partition_list)
-            logger.debug('==============================================')
+            
             
             
             created_table   = create_table_from_template(dataset_name, table_template_name, table_scheme,
@@ -275,6 +304,12 @@ def stream_data_by_datetime_partition(bigquery_client, dataset_name, table_templ
                                              bigquery_client=bigquery_client)
             
             
+            logger.debug('==============================================')
+            logger.debug('partition_value_str=%s' , partition_value_str)
+            logger.debug('partition_list=%s' , partition_list)
+            logger.debug('created_table=%s' , created_table)
+            logger.debug('==============================================')
+            
             __errors = bigquery_client.insert_rows_json(created_table, partition_list)
             
             if len(__errors)>0:
